@@ -3,16 +3,16 @@ library(fingertipsR)
 
 context("fingertips data extract")
 
-df1 <- fingertips_data(IndicatorID = 259)
-df2 <- suppressWarnings(fingertips_data(IndicatorID = 259, DomainID = 2000008))
-df3 <- suppressWarnings(fingertips_data(IndicatorID = 259, ProfileID = 20))
+df1 <- fingertips_data(IndicatorID = 90616, AreaTypeID = 152)
+df2 <- suppressWarnings(fingertips_data(IndicatorID = 90616, AreaTypeID = 152, DomainID = 1938133106))
+df3 <- suppressWarnings(fingertips_data(IndicatorID = 90616, AreaTypeID = 152, ProfileID = 135))
 df4 <- fingertips_data(DomainID = 1938132767)
 df5 <- fingertips_data(ProfileID = 132)
-df6 <- fingertips_data(IndicatorID = 259, ProfileID = NA)
+df6 <- fingertips_data(IndicatorID = 90616, AreaTypeID = 152, ProfileID = NA)
 df7 <- fingertips_data(DomainID = 1938132767, AreaCode = "E06000015")
 df8 <- fingertips_data(DomainID = 1938132767, rank = TRUE)
 
-ncols <- 25
+ncols <- 26
 
 test_that("the data returned are the same despite different inputs", {
         expect_equal(df1, df2)
